svarog package
==============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   svarog.dispatchers

Submodules
----------

svarog.checks module
--------------------

.. automodule:: svarog.checks
   :members:
   :undoc-members:
   :show-inheritance:

svarog.compat module
--------------------

.. automodule:: svarog.compat
   :members:
   :undoc-members:
   :show-inheritance:

svarog.forges module
--------------------

.. automodule:: svarog.forges
   :members:
   :undoc-members:
   :show-inheritance:

svarog.svarog module
--------------------

.. automodule:: svarog.svarog
   :members:
   :undoc-members:
   :show-inheritance:

svarog.types module
-------------------

.. automodule:: svarog.types
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: svarog
   :members:
   :undoc-members:
   :show-inheritance:
